
* Set working directory

cd "replication_data"
set more off
est clear
set matsize 11000



*************************************************************************************************************************************************
* TABLE A9
*************************************************************************************************************************************************

do "var_coding/create pg"

xtset CRCode
set more off
est clear

* column 1

eststo: fp <l_pop_census_over18>, zero replace: areg placebo_2009 placebo_2000 l_e_over18_Badiaran-l_a_building_cu i.type2 i_q15_2000-i_q27_2000 <l_pop_census_over18>, absorb(CRCode) vce(cluster CRCode)

test 3.type2 - 1.type2 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2 - 2.type2 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))


* column 2

preserve

replace placebo_2009 = log(placebo_2009 + 1)
replace placebo_2000 = log(placebo_2000 + 1)  

eststo: fp <l_pop_census_over18>, zero replace: areg placebo_2009 placebo_2000 l_e_over18_Badiaran-l_a_building_cu i.type2 i_q15_2000-i_q27_2000 <l_pop_census_over18>, absorb(CRCode) vce(cluster CRCode)

test 3.type2 - 1.type2 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2 - 2.type2 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))

restore


* column 3

gen placebo_change = placebo_2009 - placebo_2000
recode placebo_change (-4/0=0)(1/4 = 1)

eststo: fp <l_pop_census_over18>, zero replace: areg placebo_change placebo_2000 l_e_over18_Badiaran-l_a_building_cu i.type2 i_q15_2000-i_q27_2000 <l_pop_census_over18>, absorb(CRCode) vce(cluster CRCode)

test 3.type2 - 1.type2 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2 - 2.type2 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))



* column 4

eststo: fp <l_pop_census_over18>, zero replace: poisson placebo_2009 placebo_2000 l_e_over18_Badiaran-l_a_building_cu i.type2 i_q15_2000-i_q27_2000 i.CRCode <l_pop_census_over18>, vce(cluster CRCode)

test 3.type2 - 1.type2 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = normal(`test5'*sqrt(r(chi2)))

test 3.type2 - 2.type2 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = normal(`test6'*sqrt(r(chi2)))


esttab est1 est2 est3 est4 using "output/appendix_regressions.tex", label title(Placebo results on learning after one election \label{placebo}) ///
coeflabels(1.type2 "Mixed support" 2.type2 "non-PDS support" 3.type2 "PDS support") eqlabels(none) ///
stats(N test5 test6 ar2, fmt(0 3) labels("Observations" "Mixed support $\geq$ PDS support" "non-PDS support $\geq$ PDS support" "$R^2$")) ///
b(3) se(3) drop(0.type2 l_* i_q* *.CRCode) replace


*************************************************************************************************************************************************
* TABLE A10
*************************************************************************************************************************************************

do "var_coding/create iv"

est clear
set matsize 11000
set more off

xtset CRCode
drop if CRCode == 11135 /* manually drop single-obs CR because e(sample) doesn't work for removing it with xtivreg */

* first column
eststo: xtreg signal2000 rank_pop school2000 rankschool pg_all2000 l_pop_census_over18-l_a_building_cu i_q15_2000-i_q27_2000, fe vce(cluster CRCode)
test rankschool
estadd scalar fs1 = `r(F)'
estadd scalar rsq = e(r2_a)

* second column
eststo: fp <l_pop_census_over18>, zero replace: areg pg_all2009 signal2000 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i_q15_2000-i_q27_2000 <l_pop_census_over18>, absorb(CRCode) vce(cluster CRCode)
estadd scalar rsq = e(r2_a)


* third column
eststo: xtivreg2 pg_all2009 pg_all2000 l_pop_census_over18-l_a_building_cu i_q15_2000-i_q27_2000 /// /* usual controls */
school2000 rank_pop  /// /* new subinteractions */
(signal2000 = /// /* being instrumented */
rankschool), fe robust cluster(CRCode) savefirst /* instruments */
estadd scalar rsq = e(r2_a)

estimates restore _xtivreg2_signal2000
test rankschool
estadd scalar fs1 = `r(F)'


* create the table
esttab using "output/appendix_regressions.tex", label title(Regression using Instrument \label{ivreg}) ///
coeflabels(rank_pop "Population rank") ///
eqlabels(none) b(3) se(3) stats(N fs1 rsq, fmt(0 3) ///
labels("Observations" "F-Statistic" "Adjusted R$^2$")) ///
drop(l_* i_q*) append



*************************************************************************************************************************************************
* TABLE A11
*************************************************************************************************************************************************


est clear
set more off

eststo: xtreg signal2000 c.rank_pop##school2000 pg_all2000 l_pop_census_over18-l_a_building_cu i_q15_2000-i_q27_2000, fe vce(cluster CRCode)
testparm school2000#c.rank_pop
estadd scalar fs1 = `r(F)'
estadd scalar rsquare = e(r2_a)


foreach p of varlist health2000 water2000 road2000 i_q15_2000-i_q27_2000 pavedroad2000 electric2000 {

	eststo: xtreg signal2000 c.rank_pop##`p' school2000 c.rank_pop#school2000 pg_all2000 l_pop_census_over18-l_a_building_cu i_q17_2000-i_q27_2000, fe vce(cluster CRCode)
	
	testparm `p'#c.rank_pop
	estadd scalar fs1 = `r(F)'
	
	testparm school2000#c.rank_pop
	estadd scalar fs2 = `r(F)'

	estadd scalar rsquare = e(r2_a)
}

esttab est1 est2 est3 est4 est5 est6 est7 est8 est9 /// 
using "output/appendix_regressions.tex", label title(Placebo Instrument \label{instrument}) ///
eqlabels(none) b(3) se(3) stats(N fs2 fs1 rsquare, fmt(0 3) ///
labels("Observations" "F-Statistic (School $\times$ rank)" "F-Statistic (Placebo $\times$ rank)" "Adjusted R$^2$")) ///
drop(0.* l_* i_q* pg_all2000 rank_pop school2000) append

esttab est10 est11 est12 est13 est14 est15 est16 est17 est18 ///
using "output/appendix_regressions.tex", label title(Placebo Instrument \label{instrument}) ///
eqlabels(none) b(3) se(3) stats(N fs2 fs1 rsquare, fmt(0 3) ///
labels("Observations" "F-Statistic (School $\times$ rank)" "F-Statistic (Placebo $\times$ rank)" "Adjusted R$^2$")) ///
drop(0.* l_* i_q* pg_all2000 rank_pop school2000) append


*************************************************************************************************************************************************
* TABLE A12
*************************************************************************************************************************************************

do "var_coding/create pg"

set more off
est clear

* column 1

eststo: fp <l_pop_census_over18>, zero replace: areg signal2007 signal2000 l_e_over18_Badiaran-l_a_building_cu i.type2 i_q15_2000-i_q27_2000 <l_pop_census_over18>, absorb(CRCode) vce(cluster CRCode)


test 2.type2 - 1.type2 = 0
local test4 = sign(_b[1.type2]-_b[2.type2])
estadd scalar test4 = 1 - ttail(r(df_r),`test4'*sqrt(r(F)))

test 3.type2 - 1.type2 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2 - 2.type2 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))


* column 2

gen poll_change1 = signal2007-signal2000
recode poll_change1 (-4/0=0)(1/4 = 1)
label var poll_change1 "$\Delta$ Polling Stations"

eststo: fp <l_pop_census_over18>, zero replace: areg poll_change1 signal2000 l_e_over18_Badiaran-l_a_building_cu i.type2 i_q15_2000-i_q27_2000 <l_pop_census_over18>, absorb(CRCode) vce(cluster CRCode)


test 2.type2 - 1.type2 = 0
local test4 = sign(_b[1.type2]-_b[2.type2])
estadd scalar test4 = 1 - ttail(r(df_r),`test4'*sqrt(r(F)))

test 3.type2 - 1.type2 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2 - 2.type2 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))


esttab est1 est2 using "output/appendix_regressions.tex", label title(Predicting Polling Stations \label{roundtwo}) ///
coeflabels(1.type2 "Mixed support" 2.type2 "Non-PDS support" 3.type2 "PDS support") eqlabels(none) ///
stats(N test4 test5 test6 ar2, fmt(0 3) labels("Observations" "Mixed support $\geq$ Non-PDS support" "Mixed support $\geq$ PDS support" "Non-PDS support $\geq$ PDS support" "$R^2$")) ///
b(3) se(3) drop(0.type2 l_* i_q*) append	

*************************************************************************************************************************************************
* TABLE A13
*************************************************************************************************************************************************


set more off
est clear

do "var_coding/create pg 20-80-1"
xtset CRCode

* column 4 (do this first for e(sample))

eststo: fp <l_pop_census_over18>, zero replace: xtpois pg_all2009 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2_80 i_q15_2000-i_q27_2000 <l_pop_census_over18>, fe vce(robust)

gen sample = e(sample)

test 3.type2_80 - 1.type2_80 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = normal(`test5'*sqrt(r(chi2)))

test 3.type2_80 - 2.type2_80 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = normal(`test6'*sqrt(r(chi2)))


* column 1

eststo: fp <l_pop_census_over18>, zero replace: areg pg_all2009 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2_80 i_q15_2000-i_q27_2000 <l_pop_census_over18> if sample == 1, absorb(CRCode) vce(cluster CRCode)

test 3.type2_80 - 1.type2_80 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2_80 - 2.type2_80 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))


* column 2

preserve

replace pg_all2009 = log(pg_all2009 + 1)
replace pg_all2000 = log(pg_all2000 + 1)

eststo: fp <l_pop_census_over18>, zero replace: areg pg_all2009 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2_80 i_q15_2000-i_q27_2000 <l_pop_census_over18> if sample == 1, absorb(CRCode) vce(cluster CRCode)

test 3.type2_80 - 1.type2_80 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2_80 - 2.type2_80 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))

restore


* column 3

gen pg_change1 = pg_all2009-pg_all2000
recode pg_change1 (-4/0=0)(1/4 = 1)
label var pg_change1 "$\Delta$ Access"

eststo: fp <l_pop_census_over18>, zero replace: areg pg_change1 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2_80 i_q15_2000-i_q27_2000 <l_pop_census_over18> if sample == 1, absorb(CRCode) vce(cluster CRCode)


test 3.type2_80 - 1.type2_80 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2_80 - 2.type2_80 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))



esttab est2 est3 est4 est1 using "output/appendix_regressions.tex", label title(Results on learning after one election, using 20\% and 80\% cutoffs \label{recode}) ///
coeflabels(1.type2_80 "Mixed support" 2.type2_80 "Non-Wade support" 3.type2_80 "Wade support") eqlabels(none) ///
stats(N test5 test6 ar2, fmt(0 3) labels("Observations" "Mixed support $\geq$ Wade support" "Non-Wade support $\geq$ Wade support" "$R^2$")) ///
b(3) se(3) drop(l_* i_q*) append	

*************************************************************************************************************************************************
* TABLE A14
*************************************************************************************************************************************************

set more off
est clear

do "var_coding/create pg"
do "var_coding/create dynamic"

xtset CRCode

* column 4 (do this first for e(sample))

eststo: fp <l_pop_census_over18>, zero replace: xtpois pg_all2009 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2nd i_q15_2000-i_q27_2000 <l_pop_census_over18>, fe vce(robust)

gen sample = e(sample)

test 3.type2nd - 1.type2nd = 0
local test5 = sign(_b[1.type2nd]-_b[3.type2nd])
estadd scalar test5 = normal(`test5'*sqrt(r(chi2)))

test 3.type2nd - 2.type2nd = 0
local test6 = sign(_b[2.type2nd]-_b[3.type2nd])
estadd scalar test6 = normal(`test6'*sqrt(r(chi2)))


* column 1

eststo: fp <l_pop_census_over18>, zero replace: areg pg_all2009 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2nd i_q15_2000-i_q27_2000 <l_pop_census_over18> if sample == 1, absorb(CRCode) vce(cluster CRCode)

test 3.type2nd - 1.type2nd = 0
local test5 = sign(_b[1.type2nd]-_b[3.type2nd])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2nd - 2.type2nd = 0
local test6 = sign(_b[2.type2nd]-_b[3.type2nd])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))


* column 2

preserve

replace pg_all2009 = log(pg_all2009 + 1)
replace pg_all2000 = log(pg_all2000 + 1)

eststo: fp <l_pop_census_over18>, zero replace: areg pg_all2009 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2nd i_q15_2000-i_q27_2000 <l_pop_census_over18> if sample == 1, absorb(CRCode) vce(cluster CRCode)

test 3.type2nd - 1.type2nd = 0
local test5 = sign(_b[1.type2nd]-_b[3.type2nd])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2nd - 2.type2nd = 0
local test6 = sign(_b[2.type2nd]-_b[3.type2nd])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))

restore



* column 3

gen pg_change1 = pg_all2009-pg_all2000
recode pg_change1 (-4/0=0)(1/4 = 1)
label var pg_change1 "$\Delta$ Access"

eststo: fp <l_pop_census_over18>, zero replace: areg pg_change1 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2nd i_q15_2000-i_q27_2000 <l_pop_census_over18> if sample == 1, absorb(CRCode) vce(cluster CRCode)


test 3.type2nd - 1.type2nd = 0
local test5 = sign(_b[1.type2nd]-_b[3.type2nd])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2nd - 2.type2nd = 0
local test6 = sign(_b[2.type2nd]-_b[3.type2nd])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))


esttab est2 est3 est4 est1 using "output/appendix_regressions.tex", label title(Second round results on learning after one election (testing of Hypotheses 1 and 2) \label{roundtwo}) ///
coeflabels(1.type2nd "Mixed support" 2.type2nd "Non-PDS support" 3.type2nd "PDS support") eqlabels(none) ///
stats(N test5 test6 ar2, fmt(0 3) labels("Observations" "Mixed support $\geq$ PDS support" "Non-PDS support $\geq$ PDS support" "$R^2$")) ///
b(3) se(3) drop(0.type2nd l_* i_q*) append	


*************************************************************************************************************************************************
* TABLE A15
*************************************************************************************************************************************************

set more off
est clear
drop sample

* column 1

fp <l_pop_census_over18>, zero replace: xtpois pg_all2009 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2nd i_q15_2000-i_q27_2000 <l_pop_census_over18>, fe vce(robust)

gen sample = e(sample)

eststo: fp <l_pop_census_over18>, zero replace: areg pg_all2009 i.type2nd pg_all2000 l_e_over18_Badiaran-l_a_building_cu i_q15_2000-i_q27_2000 <l_pop_census_over18> if sample == 1, absorb(CRCode) vce(cluster CRCode)


test 1.type2nd - 2.type2nd = 0
local test1 = sign(_b[2.type2nd]-_b[1.type2nd])
estadd scalar test1 = 1 - ttail(r(df_r),`test1'*sqrt(r(F)))

test 3.type2nd - 2.type2nd = 0
local test2 = sign(_b[2.type2nd]-_b[3.type2nd])
estadd scalar test2 = 1 - ttail(r(df_r),`test2'*sqrt(r(F)))

test 3.type2nd - 1.type2nd = 0
local test3 = sign(_b[1.type2nd]-_b[3.type2nd])
estadd scalar test3 = 1 - ttail(r(df_r),`test3'*sqrt(r(F)))


* column 2

preserve 

eststo: fp <l_pop_census_over18>, zero replace: areg pg_all2009 always_mixed_2nd ever_switch_2nd always_ps_2nd pg_all2000 l_e_over18_Badiaran-l_a_building_cu i_q15_2000-i_q27_2000 <l_pop_census_over18>, absorb(CRCode) vce(cluster CRCode)

test always_mixed_2nd - always_ps_2nd = 0
local test4 = sign(_b[always_ps_2nd]-_b[always_mixed_2nd])
estadd scalar test4 = 1 - ttail(r(df_r),`test4'*sqrt(r(F)))

test ever_switch_2nd - always_ps_2nd = 0
local test5 = sign(_b[always_ps_2nd]-_b[ever_switch_2nd])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test ever_switch_2nd - always_mixed_2nd = 0
local test6 = sign(_b[always_mixed_2nd]-_b[ever_switch_2nd])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))

restore

esttab est1 est2 using "output/appendix_regressions.tex", label title(Second round results on learning after two elections (testing of Hypothesis 3) \label{dynamic}) ///
coeflabels(1.type2nd "Mixed support" 2.type2nd "PS support" 3.type2nd "PDS support") eqlabels(none) ///
stats(N test1 test2 test3 test4 test5 test6 ar2, fmt(0 3) ///
labels("Observations" "Always non-PDS $\geq$ Always mixed" "Always non-PDS $\geq$ Ever PDS" "Always mixed $\geq$ Ever PDS" ///
 "Same non-PDS $\geq$ Always mixed" "Same non-PDS $\geq$ Ever switched" "Always mixed $\geq$ Ever switched" "$R^2$")) ///
b(3) se(3) drop(l_* i_q*) append



*************************************************************************************************************************************************
* A16
*************************************************************************************************************************************************

drop sample
do "var_coding/create turnout"

est clear
set matsize 11000
set more off


* column 4

xtset CRCode
eststo: fp <l_pop_census_over18>, zero replace: xtpois pg_all2009 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2 i_q15_2000-i_q27_2000 <l_pop_census_over18>, fe vce(robust)

gen sample = e(sample)

test 2.type2 - 1.type2 = 0
local test4 = sign(_b[1.type2]-_b[2.type2])
estadd scalar test4 = normal(`test4'*sqrt(r(chi2)))

test 3.type2 - 1.type2 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = normal(`test5'*sqrt(r(chi2)))

test 3.type2 - 2.type2 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = normal(`test6'*sqrt(r(chi2)))


* column 1

eststo: fp <l_pop_census_over18>, zero replace: areg pg_all2009 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2 i_q15_2000-i_q27_2000 <l_pop_census_over18> if sample == 1, absorb(CRCode) vce(cluster CRCode)


test 2.type2 - 1.type2 = 0
local test4 = sign(_b[1.type2]-_b[2.type2])
estadd scalar test4 = 1 - ttail(r(df_r),`test4'*sqrt(r(F)))

test 3.type2 - 1.type2 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2 - 2.type2 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))


* column 2

preserve

replace pg_all2009 = log(pg_all2009 + 1)
replace pg_all2000 = log(pg_all2000 + 1)

eststo: fp <l_pop_census_over18>, zero replace: areg pg_all2009 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2 i_q15_2000-i_q27_2000 <l_pop_census_over18> if sample == 1, absorb(CRCode) vce(cluster CRCode)

test 2.type2 - 1.type2 = 0
local test4 = sign(_b[1.type2]-_b[2.type2])
estadd scalar test4 = 1 - ttail(r(df_r),`test4'*sqrt(r(F)))

test 3.type2 - 1.type2 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2 - 2.type2 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))

restore


* column 3

gen pg_change1 = pg_all2009-pg_all2000
recode pg_change1 (-4/0=0)(1/4 = 1)
label var pg_change1 "$\Delta$ Access"

eststo: fp <l_pop_census_over18>, zero replace: areg pg_change1 pg_all2000 l_e_over18_Badiaran-l_a_building_cu i.type2 i_q15_2000-i_q27_2000 <l_pop_census_over18> if sample == 1, absorb(CRCode) vce(cluster CRCode)

test 2.type2 - 1.type2 = 0
local test4 = sign(_b[1.type2]-_b[2.type2])
estadd scalar test4 = 1 - ttail(r(df_r),`test4'*sqrt(r(F)))

test 3.type2 - 1.type2 = 0
local test5 = sign(_b[1.type2]-_b[3.type2])
estadd scalar test5 = 1 - ttail(r(df_r),`test5'*sqrt(r(F)))

test 3.type2 - 2.type2 = 0
local test6 = sign(_b[2.type2]-_b[3.type2])
estadd scalar test6 = 1 - ttail(r(df_r),`test6'*sqrt(r(F)))


esttab est2 est3 est4 est1 using "output/appendix_regressions.tex", label title(Recoding Type Using Turnout \label{turnout}) ///
coeflabels(1.type2 "Mixed support" 2.type2 "Non-PDS support" 3.type2 "PDS support") eqlabels(none) ///
stats(N test4 test5 test6 ar2, fmt(0 3) labels("Observations" "Mixed support $\geq$ Non-PDS support" "Mixed support $\geq$ PDS support" "Non-PDS support $\geq$ PDS support" "$R^2$")) ///
b(3) se(3) drop(0.type2 l_* i_q*) append
