

clear
capture cd "replication_data"
set more off
est clear

quietly {
use "main_data.dta", replace
drop if CRName == "Touba Mosquee" | CRName == "Velingara"


* Merge 2012 data

preserve
use "2012_elections_final.dta", clear
foreach var of varlist type-mackysall_2nd {
	ren `var' `var'_2012
}
duplicates drop VillageCodeCensus, force
drop dupmatch dups
tempfile formatching
save `formatching'
restore

merge m:1 VillageCodeCensus using `formatching'
drop if _merge == 2
rename _merge signal_2012
}


*************************************************************************************************************************************************
* FIGURE A1
*************************************************************************************************************************************************


quietly {

* 2000
gen water2000=0
replace water2000=1 if q4_2000==1 | q5_2000==1 | q6_2000==1
gen school2000=0
replace school2000=1 if q9_2000==1 | q10_2000==1
gen health2000=0
replace health2000=1 if q11_2000==1 | q12_2000==1
gen road2000=0
replace road2000=1 if q14_2000==1

label var water2000 "Access to water (2000)"
label var school2000 "Access to schools (2000)"
label var health2000 "Access to healthcare (2000)"
label var road2000 "Access to unpaved road (2000)"

* 2009
gen water2009=0
replace water2009=1 if q4_2009==1 | q5_2009==1 | q6_2009==1
generate school2009=0
replace school2009=1 if q9_2009==1 | q10_2009==1
generate health2009=0
replace health2009=1 if q12_2009==1 | q11_2009==1
gen road2009=0
replace road2009=1 if q14_2009==1 

label var water2009 "Access to water (2009)"
label var school2009 "Access to schools (2009)"
label var health2009 "Access to healthcare (2009)"
label var road2009 "Access to unpaved road (2009)"


gen pavedroad2000 = 0
gen electric2000 = 0

label var pavedroad2000 "Paved road (2000)"
label var electric2000 "Electric line (2000)"

replace pavedroad2000 = 1 if q13_2000 == 1
replace electric2000 = 1 if q16_2000 == 1


gen pavedroad2009 = 0
gen electric2009 = 0

label var pavedroad2009 "Paved road (2009)"
label var electric2009 "Electric line (2009)"

replace pavedroad2009 = 1 if q13_2009 == 1
replace electric2009 = 1 if q16_2009 == 1


foreach var of varlist q15_2000 q17_2000-q27_2000 {
	gen i_`var' = 0
	replace i_`var' = 1 if `var' == 1
}

label var i_q15_2000 "Phone line"
label var i_q17_2000 "Electricity post"
label var i_q18_2000 "Market 1"
label var i_q19_2000 "Market 2"
label var i_q20_2000 "Market 3"
label var i_q21_2000 "Market 4"
label var i_q22_2000 "Market 5"
label var i_q23_2000 "Market 6"
label var i_q24_2000 "Market 7"
label var i_q25_2000 "Market 8"
label var i_q26_2000 "Cattle feed"
label var  i_q27_2000 "Artisans guild"


foreach var of varlist water2000-i_q27_2000 {
	display "`var'"
	count if `var' == 1
	display `r(N)'/11060
}

foreach var of varlist radio-building {
	gen share_`var' = `var'/pop_census
}

}

graph bar water2000 water2009, ylab(0(0.2)0.8)
graph bar road2000 road2009, ylab(0(0.2)0.8)
graph bar school2000 school2009, ylab(0(0.2)0.8)
graph bar health2000 health2009, ylab(0(0.2)0.8)


*************************************************************************************************************************************************
* TABLE A1
*************************************************************************************************************************************************

quietly {
* signal vars
gen signal2000 = 1
replace signal2000 = 0 if signal_2000 == 1
gen signal2007 = 1
replace signal2007 = 0 if signal_2007 == 1
gen signal2012 = 1
replace signal2012= 0 if signal_2012 == 1

* for 2000

egen max2000 = rowmax(ibaderthiam-abdoudiouf)
gen maxshare2000 = max2000/exprimes
gen bloc2000 = .
replace bloc2000 = 1 if signal2000 == 1 & maxshare2000 >= 0.66 & maxshare2000 <= 1
replace bloc2000 = 0 if signal2000 == 1 & maxshare2000 < 0.66 & maxshare2000 >= 0
gen nonPDSbloc_2000 = bloc2000
replace nonPDSbloc_2000 = 0 if bloc2000 == 1 & max2000 == abdoulayewade

gen wadeshare2000 = abdoulayewade/exprimes
gen type2000 = .
replace type2000 = 1 if bloc2000 == 0
replace type2000 = 2 if nonPDSbloc_2000 == 1
replace type2000 = 3 if wadeshare2000 >= 0.66 & wadeshare2000 <= 1
replace type2000 = 0 if signal2000 == 0


* for 2007

egen max2007 = rowmax(moustaphaniasse_2007-tallasylla_2007)
gen maxshare2007 = max2007/exprimes_2007
gen bloc2007 = .
replace bloc2007 = 1 if signal2007 == 1 & maxshare2007 >= 0.66 & maxshare2007 <= 1
replace bloc2007 = 0 if signal2007 == 1 & maxshare2007 <= 0.66 & maxshare2007 >= 0
gen nonPDSbloc_2007 = bloc2007
replace nonPDSbloc_2007 = 0 if bloc2007 == 1 & max2007 == abdoulayewade_2007

gen wadeshare2007 = abdoulayewade_2007/exprimes_2007
gen type2007 = .
replace type2007 = 1 if bloc2007 == 0
replace type2007 = 2 if nonPDSbloc_2007 == 1
replace type2007 = 3 if wadeshare2007 >= 0.66 & wadeshare2007 <= 1
replace type2007 = 0 if signal2007 == 0
}

*** RESULTS:

* 2000
tab type2000

* 2007
tab type2007

* % of mixed in 2000 that switched in 2007
count if type2000 == 1 & signal2000 == 1 & signal2007 == 1
count if type2000 == 1 & (type2007 == 2 | type2007 == 3)
di 951/2514

* % of non-PDS in 2000 that switched in 2007
count if type2000 == 2 & signal2000 == 1 & signal2007 == 1
count if type2000 == 2 & (type2007 == 1 | type2007 == 3)
di 1030/1092

*************************************************************************************************************************************************
* TABLE A2
*************************************************************************************************************************************************

quietly{

* 2000 bloc voting

foreach var of varlist ibaderthiam-abdoudiouf {
	gen `var'_bloc2000 = 0
	replace `var'_bloc2000 = 1 if bloc2000 == 1 & `var' == max2000
}

* 2007 bloc voting

foreach var of varlist moustaphaniasse_2007-tallasylla_2007 {
	gen `var'_bloc = 0
	replace `var'_bloc = 1 if bloc2007 == 1 & `var' == max2007
}


* villages that bloc-voted in 2012:
egen max2012 = rowmax(niasse_2012-ssidibe_2012)
gen maxshare2012 = max2012/exprimes_2012
gen bloc2012 = .
replace bloc2012 = 1 if signal2012 == 1 & maxshare2012 >= 0.66 & maxshare2012 <= 1
replace bloc2012 = 0 if signal2012 == 1 & maxshare2012 < 0.66 & maxshare2012 >= 0

foreach var of varlist niasse_2012-ssidibe_2012 {
	gen `var'_bloc = 0
	replace `var'_bloc = 1 if bloc2012 == 1 & `var' == max2012
}

}

*** RESULTS:

*2000

count if signal2000	== 1
count if bloc2000 == 1 & signal2000 == 1
di 1220/3838

tab abdoulayewade_bloc2000 if signal2000 == 1
tab abdoudiouf_bloc2000 if signal2000 == 1


* 2007

count if signal2007	== 1
count if bloc2007 == 1 & signal2007 == 1
di 1745/4283

tab abdoulayewade_2007_bloc if signal2007 == 1
tab ousmanetanordieng_2007_bloc if signal2007 == 1
tab idrissaseck_2007_bloc if signal2007 == 1


* 2012

count if signal2012 == 1
count if bloc2012 == 1 & signal2012 == 1
di 1003/4297

tab wade_2012_bloc if signal2012 == 1
tab dieng_2012_bloc if signal2012 == 1
tab sall_2012_bloc if signal2012 == 1
	
	
	
*************************************************************************************************************************************************
* TABLE A3-A5
*************************************************************************************************************************************************


* Table A3
estpost summarize water2000-i_q27_2000
esttab using "output/sumstats.tex", cells("mean(fmt(3))") noobs replace

* Table A4
estpost summarize pop_census_over18 share_e_over18_Badiaran-share_r_over18_Tidjane 
esttab using "output/sumstats.tex", cells("count mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))") noobs append

* Table A5
estpost summarize share_radio-share_building
esttab using "output/sumstats.tex", cells("count mean(fmt(3)) sd(fmt(3)) min(fmt(3)) max(fmt(3))") noobs append





*************************************************************************************************************************************************
* TABLE A6
*************************************************************************************************************************************************

*** 2000 to 2007:
count if signal2000 == 1 & signal2007 == 1 & exprimes != 0 & exprimes_2007 != 0

* bloc to mix
count if bloc2000 == 1 & bloc2007 == 0
di 661/3686

* stay same bloc
count if ((abdoulayewade_bloc2000 == 1 | ibaderthiam_bloc2000 == 1) & abdoulayewade_2007_bloc == 1) ///
	| (abdoudiouf_bloc2000 == 1 & ousmanetanordieng_2007_bloc == 1) ///
	| (moustaphaniasse_bloc2000 == 1 & moustaphaniasse_2007_bloc == 1) ///
	| (cheikhadieye_bloc2000 == 1 & cheikhbambadiye_2007_bloc  == 1)
di 90/3686

* mix to bloc
count if bloc2000 == 0 & bloc2007 == 1
di 951/3686

* stay mix
count if bloc2000 == 0 & bloc2007 == 0
di 1557/3686

* bloc to diff bloc
count if ((abdoulayewade_bloc2000 == 1 | ibaderthiam_bloc2000 == 1) & abdoulayewade_2007_bloc != 1 & bloc2007 == 1) ///
	| (abdoudiouf_bloc2000 == 1 & ousmanetanordieng_2007_bloc != 1 & bloc2007 == 1) ///
	| (moustaphaniasse_bloc2000 == 1 & moustaphaniasse_2007_bloc != 1 & bloc2007 == 1) ///
	| (cheikhadieye_bloc2000 == 1 & cheikhbambadiye_2007_bloc != 1 & bloc2007 == 1) ///
	| ((djiboka_bloc2000 == 1 |  madembasock_bloc2000 == 1 | ousseynoufall_bloc2000== 1 ) & bloc2007 == 1)
di 427/3686


*** 2007 to 2012:
count if signal2012 == 1 & signal2007 == 1 & exprimes_2012 != 0 & exprimes_2007 != 0

* bloc to mix
count if bloc2012 == 1 & bloc2007 == 0
di 301/4094

* stay same bloc
count if (abdoulayewade_2007_bloc == 1 & wade_2012_bloc == 1) ///
	| (idrissaseck_2007_bloc == 1 & seck_2012_bloc == 1) ///
	| (ousmanetanordieng_2007_bloc == 1 & dieng_2012_bloc == 1) ///
	| (moustaphaniasse_2007_bloc == 1 & niasse_2012_bloc == 1) ///
	| (cheikhbambadiye_2007_bloc  == 1 & dieye_2012_bloc == 1) ///
	| (doudoundoye_2007_bloc == 1 & ndoye_2012_bloc == 1)
di 562/4094

* bloc to diff bloc
count if (abdoulayewade_2007_bloc == 1 & wade_2012_bloc != 1 & bloc2012 == 1) ///
	| (idrissaseck_2007_bloc == 1 & seck_2012_bloc != 1 & bloc2012 == 1) ///
	| (ousmanetanordieng_2007_bloc == 1 & dieng_2012_bloc != 1 & bloc2012 == 1) ///
	| (moustaphaniasse_2007_bloc == 1 & niasse_2012_bloc != 1 & bloc2012 == 1) ///
	| (cheikhbambadiye_2007_bloc  == 1 & dieye_2012_bloc != 1 & bloc2012 == 1) ///
	| (doudoundoye_2007_bloc == 1 & ndoye_2012_bloc != 1 & bloc2012 == 1) ///
	| ((abdoulayebathily_2007_bloc == 1 | mamadoulaminediallo_2007_bloc == 1 ///
	| robertsagna_2007_bloc == 1 | landingsavan_2007_bloc == 1 ///
	| mameadamaguye_2007_bloc == 1 | modoudia_2007_bloc == 1 | aliounembaye_2007_bloc == 1 ///
	| louisjacquessenghor_2007_bloc == 1 | tallasylla_2007_bloc == 1 ) & bloc2012 == 1)
di 97/4094

* mix to bloc
count if bloc2012 == 0 & bloc2007 == 1
di 1007/4094

* stay mix
count if bloc2012 == 0 & bloc2007 == 0
di 2127/4094



*** 2000 to 2012:
count if signal2000 == 1 & signal2012 == 1 & exprimes != 0 & exprimes_2012 != 0

* bloc to mix
count if bloc2000 == 1 & bloc2012 == 0
di 844/3632

* stay same bloc
count if ((abdoulayewade_bloc2000 == 1 | ibaderthiam_bloc2000 == 1) & wade_2012_bloc == 1) ///
	| (abdoudiouf_bloc2000 == 1 & dieng_2012_bloc == 1) ///
	| (moustaphaniasse_bloc2000 == 1 & niasse_2012_bloc == 1) ///
	| (cheikhadieye_bloc2000 == 1 & dieye_2012_bloc == 1)
di 48/3632

* bloc to diff bloc
count if ((abdoulayewade_bloc2000 == 1 | ibaderthiam_bloc2000 == 1) & wade_2012_bloc != 1 & bloc2012 == 1) ///
	| (abdoudiouf_bloc2000 == 1 & dieng_2012_bloc != 1 & bloc2012 == 1) ///
	| (moustaphaniasse_bloc2000 == 1 & niasse_2012_bloc != 1 & bloc2012 == 1) ///
	| (cheikhadieye_bloc2000 == 1 & dieye_2012_bloc != 1 & bloc2012 == 1) ///
	| ((djiboka_bloc2000 == 1 |  madembasock_bloc2000 == 1 | ousseynoufall_bloc2000== 1 ) & bloc2012 == 1)
di 264/3632

* mix to bloc
count if bloc2000 == 0 & bloc2012 == 1
di 531/3632

* bloc to mix
count if bloc2000 == 0 & bloc2012 == 0
di 1945/3632



*************************************************************************************************************************************************
* TABLE A7 (BENIN)
*************************************************************************************************************************************************


use "a7_benin_data.dta", clear

quietly {
* first_share reports the vote share of the plurality party in 2011
egen first_votes11=rowmax(fcbe-g13baobab)
gen first_share11=first_votes11/suffragesexprimes

*drop if first_votes11==.

gen incumbent_party11 = ""
quietly foreach x of varlist fcbe-g13baobab { 
    replace incumbent_party11 = "`x'" if `x'==first_votes11 
}

egen first_votes15=rowmax(vote_valides_1 - vote_valides_20)
gen first_share15=first_votes15/total_valid

gen incumbent_party15 = "" 
quietly foreach x of varlist vote_valides_1-vote_valides_20 { 
    replace incumbent_party15 = "`x'" if `x'==first_votes15 
}

gen mixed11=0
replace mixed11=1 if  first_share11<.66

gen mixed15=0
replace mixed15=1 if first_share15<.66

tab incumbent_party11 if mixed11==0

generate samebloc=0
*replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="afu" & incumbent_party15==""
replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="amana" & incumbent_party15=="vote_valides_6"
*replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="anc2011" & incumbent_party15==""
*replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="anf2011" & incumbent_party15==""
*replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="cauris2" & incumbent_party15==""
replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="fcbe" & incumbent_party15=="vote_valides_6"
replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="frontdaction" & incumbent_party15=="vote_valides_4"
replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="g13baobob" & incumbent_party15=="vote_valides_12"
replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="rdlvivoten" & incumbent_party15=="vote_valides_18"
replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="rp" & incumbent_party15=="vote_valides_20"
replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="ub" & incumbent_party15=="vote_valides_8"
replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="un" & incumbent_party15=="vote_valides_19"
replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="un" & incumbent_party15=="vote_valides_7" // PRD part of UN in 2011
replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="un" & incumbent_party15=="vote_valides_20" // RB part of UN in 2011
replace samebloc=1 if mixed11==0 & mixed15==0 & incumbent_party11=="uprfe" & incumbent_party15=="vote_valides_16"
}

*** RESULTS:

*Bloc to mixed: (second number is if we just look at exact matches)
tabulate mixed11 mixed15
di 432/3502
di 339/2718


*Stayed the same bloc: .050 (.044)
tabulate samebloc

*Bloc to different bloc: 
di (284-176)/3502
di (202-119)/2718

*Mixed to bloc: 
di 515/3502
di 381/2718

*Stayed mixed: 
di 2271/3502
di 1796/2718



*************************************************************************************************************************************************
* TABLE A7 (LIBERIA)
*************************************************************************************************************************************************

use a7_liberia_data.dta, clear

quietly {
gen Bloctomixed = (bloc_vote_2005==1 &  bloc_vote_2011==0)
gen Stayedthesamebloc = (bloc_vote_2005==1 &  bloc_vote_2011==1 & candidate_2005 == candidate_2011)

* We code candidate_2005=="WEAH, George Manneh (CDC)" and candidate_2011=="TUBMAN, Winston A. (CDC)" as the same since it is the same party
replace Stayedthesamebloc = 1 if candidate_2005=="WEAH, George Manneh (CDC)"	& candidate_2011=="TUBMAN, Winston A. (CDC)"
replace Stayedthesamebloc = 1 if candidate_2005=="TUBMAN, Winston A. (NDPL)"	& candidate_2011=="TUBMAN, Winston A. (CDC)" 
replace Stayedthesamebloc = 1 if candidate_2005=="TIPOTEH, Togba-Nah (APD)"	& candidate_2011=="TIPOTEH, Togba-Nah (FAPL)"
gen Bloctodifferentbloc = (bloc_vote_2005==1 &  bloc_vote_2011==1 & candidate_2005 != candidate_2011)

* We code candidate_2005=="WEAH, George Manneh (CDC)" and candidate_2011=="TUBMAN, Winston A. (CDC)" as the same since it is the same party
replace Bloctodifferentbloc = 0 if candidate_2005=="WEAH, George Manneh (CDC)"	& candidate_2011=="TUBMAN, Winston A. (CDC)"
replace Bloctodifferentbloc = 0 if candidate_2005=="TUBMAN, Winston A. (NDPL)"	& candidate_2011=="TUBMAN, Winston A. (CDC)"
replace Bloctodifferentbloc = 0 if candidate_2005=="TIPOTEH, Togba-Nah (APD)"	& candidate_2011=="TIPOTEH, Togba-Nah (FAPL)"
gen Mixedtobloc = (bloc_vote_2005==0 &  bloc_vote_2011==1)
gen Stayedmixed = (bloc_vote_2005==0 &  bloc_vote_2011==0)

}

*** RESULTS:

sum Bloctomixed Stayedthesamebloc Bloctodifferentbloc Mixedtobloc Stayedmixed



*************************************************************************************************************************************************
* TABLE A8
*************************************************************************************************************************************************

use "a8_gottlieb2017.dta", clear

mean vote1, over(type1)
