

use updated_10k.dta, clear

*********************************
***   Ranking by population   ***
*********************************

bys in_fid:  egen rank_pop= rank(1/near_pop), track
drop if VillageCodeCensus != near_VillageCodeCensus
keep(VillageCodeCensus rank_pop)
tempfile poprank
save `poprank'

use "main_data", clear
merge m:m VillageCodeCensus using `poprank'
drop if CRName == "Touba Mosquee" | CRName == "Velingara"
drop _merge




*********************************
***   Cleaning public goods   ***
*********************************

* 2000
gen water2000=0
replace water2000=1 if q4_2000==1 | q5_2000==1 | q6_2000==1
gen school2000=0
replace school2000=1 if q9_2000==1 | q10_2000==1
gen health2000=0
replace health2000=1 if q11_2000==1 | q12_2000==1
gen road2000=0
replace road2000=1 if q14_2000==1 

label var water2000 "Water (2000)"
label var school2000 "Schools (2000)"
label var health2000 "Healthcare (2000)"
label var road2000 "Unpaved road (2000)"

* 2009
gen water2009=0
replace water2009=1 if q4_2009==1 | q5_2009==1 | q6_2009==1
generate school2009=0
replace school2009=1 if q9_2009==1 | q10_2009==1
generate health2009=0
replace health2009=1 if q12_2009==1 | q11_2009==1
gen road2009=0
replace road2009=1 if q14_2009==1 

label var water2009 "Access to water (2009)"
label var school2009 "Access to schools (2009)"
label var health2009 "Access to healthcare (2009)"
label var road2009 "Access to unpaved road (2009)"


egen pg_all2000=rowtotal(water2000 road2000 school2000 health2000)
egen pg_all2009=rowtotal(water2009 road2009 school2009 health2009)

label var pg_all2000 "Public goods index (2000)"
label var pg_all2009 "Public goods index (2009)"

* signal vars
gen signal2000 = 1
replace signal2000 = 0 if signal_2000 == 1
gen signal2002 = 1
replace signal2002 = 0 if signal_2002 == 1
gen signal2007 = 1
replace signal2007 = 0 if signal_2007 == 1

foreach var of varlist q15_2000 q17_2000-q27_2000 {
	gen i_`var' = 0
	replace i_`var' = 1 if `var' == 1
}

label var i_q15_2000 "Phone line"
label var i_q17_2000 "Electricity post"
label var i_q18_2000 "Market 1"
label var i_q19_2000 "Market 2"
label var i_q20_2000 "Market 3"
label var i_q21_2000 "Market 4"
label var i_q22_2000 "Market 5"
label var i_q23_2000 "Market 6"
label var i_q24_2000 "Market 7"
label var i_q25_2000 "Market 8"
label var i_q26_2000 "Cattle feed"
label var  i_q27_2000 "Artisans guild"

gen pavedroad2000 = 0
gen electric2000 = 0

label var pavedroad2000 "Paved road"
label var electric2000 "Electric line"

replace pavedroad2000 = 1 if q13_2000 == 1
replace electric2000 = 1 if q16_2000 == 1

* for loops
global pg2000 water2000 road2000 school2000 health2000 
global pg2009 water2009 road2009 school2009 health2009 
global pg water road school health 



*** Logs

* Logging population
gen l_pop_census_over18 = log(pop_census_over18)

label var l_pop_census_over18 "Census population over 18 (log)"
foreach pop of varlist l_pop_census_over18 {
	gen `pop'_sq = `pop'^2
	gen `pop'_cu = `pop'^3
}

* Logging ethnicity and religion
foreach eth of varlist e_over18_Badiaran-e_over18_Wolof {
	gen l_`eth' = log(`eth'+1)
}

foreach relig of varlist r_over18_Catholic-r_over18_Tidjane {
	gen l_`relig' = log(`relig'+1)
}

* Logging assets
foreach asset of varlist radio-building {
	gen l_a_`asset' = log(`asset'+1)
}

*** Quadratics and cubics

* ethnicity and religion
foreach eth of varlist l_e_over18_Badiaran-l_e_over18_Wolof {
	gen `eth'_sq = `eth'^2
	gen `eth'_cu = `eth'^3
}

foreach relig of varlist l_r_over18_Catholic-l_r_over18_Tidjane {
	gen `relig'_sq = `relig'^2
	gen `relig'_cu = `relig'^3
}

* assets
foreach asset of varlist l_a_radio-l_a_building {
	gen `asset'_sq = `asset'^2
	gen `asset'_cu = `asset'^3
}

label var rank_pop "Population Rank"



***********************************
***   Instrument interactions   ***
***********************************


gen rankschool = rank_pop*school2000
