
use "main_data", replace
drop if CRName == "Velingara" | CRName == "Touba Mosquee"


* 2000
gen water2000=0
replace water2000=1 if q4_2000==1 | q5_2000==1 | q6_2000==1
gen school2000=0
replace school2000=1 if q9_2000==1 | q10_2000==1
gen health2000=0
replace health2000=1 if q11_2000==1 | q12_2000==1
gen road2000=0
replace road2000=1 if q14_2000==1 

label var water2000 "Access to water (2000)"
label var school2000 "Access to schools (2000)"
label var health2000 "Access to healthcare (2000)"
label var road2000 "Access to unpaved road (2000)"

* 2009
gen water2009=0
replace water2009=1 if q4_2009==1 | q5_2009==1 | q6_2009==1
generate school2009=0
replace school2009=1 if q9_2009==1 | q10_2009==1
generate health2009=0
replace health2009=1 if q12_2009==1 | q11_2009==1
gen road2009=0
replace road2009=1 if q14_2009==1 


label var water2009 "Access to water (2009)"
label var school2009 "Access to schools (2009)"
label var health2009 "Access to healthcare (2009)"
label var road2009 "Access to unpaved road (2009)"


egen pg_all2000=rowtotal(water2000 road2000 school2000 health2000)
egen pg_all2009=rowtotal(water2009 road2009 school2009 health2009)

label var pg_all2000 "Public goods index (2000)"
label var pg_all2009 "Public goods index (2009)"

* signal vars
gen signal2000 = 1
replace signal2000 = 0 if signal_2000 == 1
gen signal2007 = 1
replace signal2007 = 0 if signal_2007 == 1

foreach var of varlist q15_2000 q17_2000-q27_2000 {
	gen i_`var' = 0
	replace i_`var' = 1 if `var' == 1
}

* for loops
global pg2000 water2000 road2000 school2000 health2000 
global pg2009 water2009 road2009 school2009 health2009 
global pg water road school health 




* creating placebos

gen pavedroad2000 = 0
gen electric2000 = 0

label var pavedroad2000 "Paved road (2000)"
label var electric2000 "Electric line (2000)"

replace pavedroad2000 = 1 if q13_2000 == 1
replace electric2000 = 1 if q16_2000 == 1


gen pavedroad2009 = 0
gen electric2009 = 0

label var pavedroad2009 "Paved road (2009)"
label var electric2009 "Electric line (2009)"

replace pavedroad2009 = 1 if q13_2009 == 1
replace electric2009 = 1 if q16_2009 == 1

egen placebo_2000 = rowtotal(pavedroad2000 electric2000)
egen placebo_2009 = rowtotal(pavedroad2009 electric2009)

label var placebo_2000 "Access to placebos in 2000"
label var placebo_2009 "Access to placebos in 2009"



*** Logs

* Logging population
gen l_pop_census_over18 = log(pop_census_over18)

label var l_pop_census_over18 "Census population over 18 (log)"

* Logging ethnicity and religion
foreach eth of varlist e_over18_Badiaran-e_over18_Wolof {
	gen l_`eth' = log(`eth'+1)
}

foreach relig of varlist r_over18_Catholic-r_over18_Tidjane {
	gen l_`relig' = log(`relig'+1)
}

* Logging assets
foreach asset of varlist radio-building {
	gen l_a_`asset' = log(`asset'+1)
}

*** Quadratics and cubics

* ethnicity and religion
foreach eth of varlist l_e_over18_Badiaran-l_e_over18_Wolof {
	gen `eth'_sq = `eth'^2
	gen `eth'_cu = `eth'^3
}

foreach relig of varlist l_r_over18_Catholic-l_r_over18_Tidjane {
	gen `relig'_sq = `relig'^2
	gen `relig'_cu = `relig'^3
}

* assets
foreach asset of varlist l_a_radio-l_a_building {
	gen `asset'_sq = `asset'^2
	gen `asset'_cu = `asset'^3
}


**************************
***   Creating types   ***
**************************

* type = 1: mixed
* type = 2: against wade
* type = 3: for wade

* for 2000

egen max2000 = rowmax(ibaderthiam-abdoudiouf)
gen maxshare2000 = max2000/exprimes
gen bloc2000 = .
replace bloc2000 = 1 if signal2000 == 1 & maxshare2000 >= 0.66 & maxshare <= 1
replace bloc2000 = 0 if signal2000 == 1 & maxshare2000 < 0.66 & maxshare >= 0
gen nonPDSbloc_2000 = bloc2000
replace nonPDSbloc_2000 = 0 if bloc2000 == 1 & max2000 == abdoulayewade


* for 2000
gen wadeshare2000 = abdoulayewade/exprimes
gen type2 = .
replace type2 = 1 if bloc2000 == 0
replace type2 = 2 if nonPDSbloc_2000 == 1
replace type2 = 3 if wadeshare2000 >= 0.66 & wadeshare2000 <= 1
replace type2 = 0 if signal2000 == 0


